#
# Script version 1.1
#
# Version history:
#  1.1  Added instructions to add Swap_back function
#  1.0  First version of this script
#
# This will extract the routing number from the incoming call make sure it routes on the called (not theRN) 
# and add the routing number in the CDRs
#
# Sample calls received will be like this:  
#    Request-Line: INVITE sip:1234567890;rn=8087321000;npdi=yes@162.33.160.23:5060 SIP/2.0
#    Called/To=1234567890, RN=8087321000
#
#  Text CDR will have a new parameter called RN
#  Need to add this in the Text CDR Format Start/End fields: '@{ScriptAttribute:RN}'
#
# In order to use this module, follow the steps below:
# 1- Add the "require 'r_n_cdr' statement at the top of the main script.
# 2- Add the "include RnCdr' statement in the main routing class.
# 3- Add the filter "before_filter :method => :RN_cdr" in the main routing class.
# 4- Add the filter "after_remap_filter :method => :Swap_back" in the main routing class.
# 5- LNP settings need to be:
#    profiles -> Outgoing calls LNP mode: Relay LNP Information 
#    profiles -> Incoming calls LNP mode: Forward LNP from incoming to outgoing call
# 6- Add new Text CDR value
#    Gateway -> Text CDR parameters -> CDR format (Start): ,RN='@{ScriptAttribute:RN}'
#    Gateway -> Text CDR parameters -> CDR format (End):   ,RN='@{ScriptAttribute:RN}'
# 7- Replace Text CDR value
#    Gateway -> Text CDR parameters -> CDR format (Start): ,Called='@{ScriptAttribute:Called2}'
#    Gateway -> Text CDR parameters -> CDR format (End):   ,Called='@{ScriptAttribute:Called2}'
#

module RnCdr
  
  def init_RN_cdr(params)
    params
  end
  
  def RN_cdr(params)
    call = params[:call]
    nap_lists = params[:naps]

    log_trace 1, "params = " + params.inspect
    log_trace 1, "call = " + call.inspect
    log_trace 1, "nap_lists = " + nap_lists.inspect
    
    # Check if NPDI is present
    if !call[:ported_number_npdi].nil?
      # || !call[:ported_number_npdi].empty?  -> error with "empty"
      log_trace 2, "NPDI" + call[:ported_number_npdi].inspect
      
      # Check if routing number is present
      if !call[:ported_number].nil?
        #|| !call[:ported_number].empty?
        log_trace 2, "Called:" + call[:called].inspect
        log_trace 2, "RN:" + call[:ported_number].inspect
        
        #Swap called and RN to keep called number and RN value for next steps
        new_called = call[:ported_number]
        new_RN = call[:called]
        call[:called] = new_called
        call[:ported_number] = new_RN
        
        # Add RN in CDR. The CDR format (start) and (end) must include: '@{ScriptAttribute:RN}'
        params[:bridge][:RN]= new_RN
        params[:bridge][:Called2]= new_called
        
        log_trace 2, "New Called:" + new_called.inspect
        log_trace 2, "New RN:" + new_RN.inspect
      else
        # RN is not present
        log_trace 2, "RN is not present"
      end
    else
      # NPDI is not present
      log_trace 2, "NPDI is not present"
    end
      
	  params
  end
  
  def init_Swap_back(params)
  end

  
  def Swap_back(params)
    log_trace 2, "Entering Swap back"

    call = params[:out_calls].first
    log_trace 2, "out_calls=" + params[:out_calls].inspect
    #call = params[:call]
    if !call[:ported_number_npdi].nil?
      if !call[:ported_number].nil?
        log_trace 2, "called=" + call[:called].inspect + "ported_number=" + call[:ported_number].inspect
        old_called = call[:ported_number]
        old_RN = call[:called]
        call[:called] = old_called
        call[:ported_number] = old_RN
        log_trace 2, "new_called=" + call[:called].inspect + "new_ported_number=" + call[:ported_number].inspect
      end
    end
    
    params
  end

  
end
